@@ -34,6 +34,7 @@ import { retrieve_config_file } from "./thoth"
 import { Requirements, RequirementsLock } from "./types/requirements";
 import { RuntimeEnvironment, ThothConfig } from "./types/thoth"
 import { IDependencyManagementUIState } from "./components/dependencyManagementUI"
+import { checkInstalledPackages } from "./common";
 
 /**
  * Function: Create Thoth configuration file using thamos library on the backend
@@ -64,7 +65,6 @@ async function _handle_runtime_environment(
     const runtime_environments: RuntimeEnvironment[] = processed_thoth_config.runtime_environments
     const runtime_environment: RuntimeEnvironment = processed_thoth_config.runtime_environments[0]
 
-    // TODO: Assign user recommendation type to all runtime environments in thoth config?
     _.set(runtime_environment, "name", kernel_name)
     _.set(runtime_environment, "recommendation_type", recommendation_type)
     _.set(runtime_environments, 0, runtime_environment)
@@ -341,15 +341,12 @@ export async function parse_inputs_from_metadata(
  * Function: Retrieve installed packages from kernel.
  */
 
-async function retrieveInstalledPackages(kernel_name: string, packages: {}): Promise<{}> {
+async function retrieveInstalledPackages(kernel_packages: {}, packages: {}): Promise<{}> {
 
-    // Retrieve installed packages
-    const retrieved_packages = await discover_installed_packages( kernel_name )
-
-    console.debug("packages installed (pip list)", retrieved_packages);
+    console.debug("packages installed (pip list)", kernel_packages);
     const installed_packages = {}
 
-    _.forIn(retrieved_packages, function(version, name) {
+    _.forIn(kernel_packages, function(version, name) {
       if (_.has(packages, name.toLowerCase())) {
         if ( _.get(packages, name.toLowerCase()) == version) {
           _.set(installed_packages, name, version)
@@ -362,23 +359,7 @@ async function retrieveInstalledPackages(kernel_name: string, packages: {}): Pro
   }
 
 
-/**
- * Function: Check installed packages and verify pipfile.lock are all in installed list
- */
-
-async function checkInstalledPackages(installed_packages: {}, packages: {}): Promise<boolean> {
-    _.forIn(packages, function(version, name) {
-        if (_.has(installed_packages, name.toLowerCase()) && _.get(installed_packages, name.toLowerCase()) == version ) {
-            console.debug( `Package '${ name }' in version '${ version }' is already installed` )
-        }
-        else {
-            return false
-        }
-    })
-    return true
-}
-
-export async function  _handle_requirements_lock(
+export async function _handle_requirements_lock(
     initial_loaded_requirements_lock: RequirementsLock,
     panel: NotebookPanel,
     ui_state: IDependencyManagementUIState,
@@ -425,8 +406,10 @@ export async function  _handle_requirements_lock(
     console.debug("loaded packages from pipfile", ui_state.loaded_packages)
     console.debug("loaded packages from pipfile lock", initial_locked_packages)
     console.debug("packages in pipfile and pipfile lock", check_packages)
+    const kernel_packages = await discover_installed_packages( kernel_name )
+    console.debug("kernel packages", kernel_packages)
 
-    const installed_packages = await retrieveInstalledPackages(kernel_name, initial_locked_packages)
+    const installed_packages = await retrieveInstalledPackages(kernel_packages, initial_locked_packages)
 
     console.debug("packages from kernel and pipfile lock", installed_packages)
 
@@ -444,8 +427,8 @@ export async function  _handle_requirements_lock(
     if ( _.isEqual(_.size(ui_state.loaded_packages), _.size(check_packages) )) {
 
         // check if all requirements locked are also installed in the current kernel
-        const are_installed: boolean = await checkInstalledPackages(installed_packages, initial_locked_packages)
-
+        const are_installed: boolean = await checkInstalledPackages(kernel_packages, initial_locked_packages)
+        console.debug("are packages installed?", are_installed)
         // if locked requirements are present in the kernel (match packages installed)
         if ( are_installed == true ) {
 
